.. _halo-analysis:

Halo Analysis
=============

This section covers halo finding, performing extra analysis on halos,
and the halo mass function calculator.  If you already have halo
catalogs and simply want to load them into yt, see
:ref:`halo-catalog-data`.

.. toctree::
   :maxdepth: 2

   halo_catalogs
   halo_mass_function
   halo_transition
   halo_merger_tree
   ellipsoid_analysis
